@@ -467,8 +467,8 @@ class fock_space_kron:
         
         Returns
         -------
-        state: tuple
-            A tuple of state for given index
+        state: numpy array
+            A numpy array of state for given index
         """
         
         if i >= self.dimension :
@@ -477,7 +477,7 @@ class fock_space_kron:
             state = np.zeros(self.modes, dtype = int)
             state[:self.f1.modes] = self.f1.occupations(i//self.f2.dimension)
             state[self.f1.modes:] = self.f2.occupations(i%self.f2.dimension)
-            return(tuple(state))
+            return(state)
         
         
     def index(self,state):
